aboutsummaryrefslogtreecommitdiffstats
path: root/coin/provisioning/qtci-linux-RHEL-6.6-x86_64
diff options
context:
space:
mode:
Diffstat (limited to 'coin/provisioning/qtci-linux-RHEL-6.6-x86_64')
-rw-r--r--coin/provisioning/qtci-linux-RHEL-6.6-x86_64/android_linux.sh17
-rw-r--r--coin/provisioning/qtci-linux-RHEL-6.6-x86_64/libusb.sh3
-rw-r--r--coin/provisioning/qtci-linux-RHEL-6.6-x86_64/patch_qnx.sh64
3 files changed, 74 insertions, 10 deletions
diff --git a/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/libusb.sh b/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/libusb.sh
new file mode 100644
index 00000000..229e259f
--- /dev/null
+++ b/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/libusb.sh
@@ -0,0 +1,3 @@
+#!/bin/env bash
+# Required for tqtc-boot2qt/qdb
+sudo yum install -y libusb1-devel
diff --git a/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/patch_qnx.sh b/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/patch_qnx.sh
new file mode 100644
index 00000000..19993ecc
--- /dev/null
+++ b/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/patch_qnx.sh
@@ -0,0 +1,64 @@
+#!/bin/env bash
+
+#############################################################################
+##
+## Copyright (C) 2016 The Qt Company Ltd.
+## Contact: http://www.qt.io/licensing/
+##
+## This file is part of the test suite of the Qt Toolkit.
+##
+## $QT_BEGIN_LICENSE:LGPL21$
+## Commercial License Usage
+## Licensees holding valid commercial Qt licenses may use this file in
+## accordance with the commercial license agreement provided with the
+## Software or, alternatively, in accordance with the terms contained in
+## a written agreement between you and The Qt Company. For licensing terms
+## and conditions see http://www.qt.io/terms-conditions. For further
+## information use the contact form at http://www.qt.io/contact-us.
+##
+## GNU Lesser General Public License Usage
+## Alternatively, this file may be used under the terms of the GNU Lesser
+## General Public License version 2.1 or version 3 as published by the Free
+## Software Foundation and appearing in the file LICENSE.LGPLv21 and
+## LICENSE.LGPLv3 included in the packaging of this file. Please review the
+## following information to ensure the GNU Lesser General Public License
+## requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+## http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+##
+## As a special exception, The Qt Company gives you certain additional
+## rights. These rights are described in The Qt Company LGPL Exception
+## version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+##
+## $QT_END_LICENSE$
+##
+#############################################################################
+
+# Patch QNX SDK due to issues in the standard library.
+# The patches are available here:
+# http://www.qnx.com/download/feature.html?programid=27555
+# A copy of the patch must be in the root of the Coin path in
+# provisioning/qnx/patch-660-4367-RS6069_cpp-headers.zip
+
+set -e
+sha1="57a11ffe4434ad567b3c36f7b828dbb468a9e565"
+
+function InstallZipPackageFromURL {
+ url=$1
+ expectedSha1=$2
+ targetDirectory=$3
+
+ targetFile=`mktemp` || echo "Failed to create temporary file"
+ wget --tries=5 --waitretry=5 --output-document=$targetFile $url || echo "Failed to download '$url' multiple times"
+ echo "$expectedSha1 $targetFile" | sha1sum --check || echo "Failed to check sha1sum"
+
+ tempDir=`mktemp -d` || echo "Failed to create temporary directory"
+ /usr/bin/unzip -o -d $tempDir $targetFile || echo "Failed to unzip $url archive"
+ trap "sudo rm -fr $targetFile $tempDir" EXIT
+
+ sudo cp -rafv $tempDir/patches/660-4367/target/* /opt/qnx660/target/
+}
+
+echo "Patching QNX"
+
+baseBinaryPackageURL="http://${COIN_WEBSERVER_ADDRESS}/coin/provisioning/qnx/patch-660-4367-RS6069_cpp-headers.zip"
+InstallZipPackageFromURL $baseBinaryPackageURL $sha1 "/opt/qnx660/target/"
diff --git a/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/android_linux.sh b/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/android_linux.sh
index 1d0630ce..6bb7a37e 100644
--- a/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/android_linux.sh
+++ b/coin/provisioning/qtci-linux-RHEL-6.6-x86_64/android_linux.sh
@@ -35,13 +35,13 @@
# This script install Android sdk and ndk.
# It also runs update for SDK API level 18, latest SDK tools, latest platform-tools and build-tools version 23.0.3
# Build-tools version 23.0.3 is the latest usable version for Red Hat 6. Newer version of build-tools, version 24.x.x, requires GLIBC_2.14, which is not available in Red Hat 6.
# Android 16 is the minimum requirement for Qt 5.7 applications, but we need something more recent than that for building Qt itself.
# E.g The Bluetooth features that require Android 18 will disable themselves dynamically when running on an Android 16 device.
# That's why we need to use Andoid-18 API version and decision was made to use it also with Qt 5.6.
set -e
targetFolder="/opt/android"
@@ -50,7 +50,7 @@ baseUrl="http://ci-files01-hki.ci.local/input/android"
# SDK
sdkPackage="android-sdk_r24.4.1-linux.tgz"
sdkBuildToolsVersion="23.0.3"
-sdkApiLevel="android-18"
+sdkApiLevel="android-21"
sdkUrl="$baseUrl/$sdkPackage"
sdkSha1="725bb360f0f7d04eaccff5a2d57abdd49061326d"
sdkTargetFile="$targetFolder/$sdkPackage"
@@ -96,13 +96,11 @@ InstallAndroidPackage "$targetFolder" $sdkPackage $sdkUrl $sdkSha1 $sdkTargetFil
echo "Installing Android NDK version $ndkPackage..."
InstallAndroidPackage "$targetFolder" $ndkPackage $ndkUrl $ndkSha1 $ndkTargetFile "$ndkExtract" $ndkFolderName $ndkName
-# run update for Android SDK and install SDK API version 18, latest SDK tools, platform-tools and build-tools
-echo "Running Android SDK update for API version 18, SDK-tools, platform-tools and build-tools-$sdkBuildToolsVersion..."
+# run update for Android SDK and install SDK API version 21, latest SDK tools, platform-tools and build-tools
+echo "Running Android SDK update for API version 21, SDK-tools, platform-tools and build-tools-$sdkBuildToolsVersion..."
echo "y" |"$targetFolder"/sdk/tools/android update sdk --no-ui --all --filter $sdkApiLevel,tools,platform-tools,build-tools-$sdkBuildToolsVersion || echo "Failed to run update"
-# For Qt 5.6, we by default require API levels 10, 11, 16 and 18, but we can override this by setting ANDROID_API_VERSION=android-18
-# From Qt 5.7 forward, if android-16 is not installed, Qt will automatically use more recent one.
-echo 'export ANDROID_API_VERSION=android-18' >> ~/.bashrc
+echo 'export ANDROID_API_VERSION=android-21' >> ~/.bashrc
# Storage version information to ~/versions.txt, which is used to print version information to provision log.
echo "***** Android SDK *****" >> ~/versions.txt
@@ -114,4 +112,3 @@ sdkTools="$(grep Pkg.Revision "$targetFolder"/sdk/tools/source.properties | cut
echo "Android SDK Tools = $sdkTools" >> ~/versions.txt
echo "***** Android NDK *****" >> ~/versions.txt
echo "Android NDK Version = $ndkVersion" >> ~/versions.txt
-
@@ -35,13 +35,13 @@
# This script install Android sdk and ndk.
-# It also runs update for SDK API level 18, latest SDK tools, latest platform-tools and build-tools version 23.0.3
+# It also runs update for SDK API level 21, latest SDK tools, latest platform-tools and build-tools version 23.0.3
# Build-tools version 23.0.3 is the latest usable version for Red Hat 6. Newer version of build-tools, version 24.x.x, requires GLIBC_2.14, which is not available in Red Hat 6.
# Android 16 is the minimum requirement for Qt 5.7 applications, but we need something more recent than that for building Qt itself.
@@ -35,13 +35,13 @@
# Build-tools version 23.0.3 is the latest usable version for Red Hat 6. Newer version of build-tools, version 24.x.x, requires GLIBC_2.14, which is not available in Red Hat 6.
# Android 16 is the minimum requirement for Qt 5.7 applications, but we need something more recent than that for building Qt itself.
-# E.g The Bluetooth features that require Android 18 will disable themselves dynamically when running on an Android 16 device.
-# That's why we need to use Andoid-18 API version and decision was made to use it also with Qt 5.6.
+# E.g The Bluetooth features that require Android 21 will disable themselves dynamically when running on an Android 16 device.
+# That's why we need to use Andoid-21 API version in Qt 5.9.
set -e
targetFolder="/opt/android"